package com.leromro.core.service.impl;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.leromro.common.constant.CommonConstants;
import com.leromro.common.core.domain.ListPermission;
import com.leromro.core.domain.SecondOrder;
import com.leromro.core.domain.dto.HomePageDTO;
import com.leromro.core.mapper.OrgStatDataMapper;
import com.leromro.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.leromro.core.mapper.OrgStatDataMapper;
import com.leromro.core.domain.OrgStatData;
import com.leromro.core.service.IOrgStatDataService;

/**
 * 平台机构数据统计Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-04-30
 */
@Service
public class OrgStatDataServiceImpl extends ServiceImpl<OrgStatDataMapper, OrgStatData> implements IOrgStatDataService
{
    @Autowired
    private OrgStatDataMapper orgStatDataMapper;

    /**
     * 查询平台机构数据统计
     * 
     * @param orgStatDataId 平台机构数据统计主键
     * @return 平台机构数据统计
     */
    @Override
    public OrgStatData selectOrgStatDataByOrgStatDataId(Long orgStatDataId)
    {
        return orgStatDataMapper.selectOrgStatDataByOrgStatDataId(orgStatDataId);
    }

    /**
     * 查询平台机构数据统计列表
     * 
     * @param orgStatData 平台机构数据统计
     * @return 平台机构数据统计
     */
    @Override
    public List<OrgStatData> selectOrgStatDataList(OrgStatData orgStatData)
    {
        return orgStatDataMapper.selectOrgStatDataList(orgStatData);
    }

    /**
     * 新增平台机构数据统计
     * 
     * @param orgStatData 平台机构数据统计
     * @return 结果
     */
    @Override
    public Boolean insertOrgStatData(OrgStatData orgStatData)
    {
        return this.save(orgStatData);
    }

    /**
     * 修改平台机构数据统计
     * 
     * @param orgStatData 平台机构数据统计
     * @return 结果
     */
    @Override
    public Boolean updateOrgStatData(OrgStatData orgStatData)
    {
        return this.updateById(orgStatData);
    }

    /**
     * 批量删除平台机构数据统计
     * 
     * @param orgStatDataIds 需要删除的平台机构数据统计主键
     * @return 结果
     */
    @Override
    public int deleteOrgStatDataByOrgStatDataIds(Long[] orgStatDataIds)
    {
        return orgStatDataMapper.deleteOrgStatDataByOrgStatDataIds(orgStatDataIds);
    }

    /**
     * 删除平台机构数据统计信息
     * 
     * @param orgStatDataId 平台机构数据统计主键
     * @return 结果
     */
    @Override
    public int deleteOrgStatDataByOrgStatDataId(Long orgStatDataId)
    {
        return orgStatDataMapper.deleteOrgStatDataByOrgStatDataId(orgStatDataId);
    }

    @Override
    public List<OrgStatData> getCurrentOrgMonthStatDataList(HomePageDTO dto) {
        return baseMapper.getCurrentOrgMonthStatDataList(new ListPermission(SecondOrder.class, CommonConstants.CHECK_PROVINCE_CITY_DISTRICT),dto);
    }
}
